@@ -21,9 +21,11 @@
 #include "mip/HighsDomainChange.h"
 #include "mip/HighsMipSolver.h"
 #include "util/HighsCDouble.h"
+#include "util/HighsRbTree.h"
 
 class HighsCutPool;
 class HighsConflictPool;
+class HighsObjectiveFunction;
 
 class HighsDomain {
  public:
@@ -38,6 +40,7 @@ class HighsDomain {
       kModelRowLower = -4,
       kCliqueTable = -5,
       kConflictingBounds = -6,
+      kObjective = -7,
     };
     static Reason branching() { return Reason{kBranching, 0}; }
     static Reason unspecified() { return Reason{kUnknown, 0}; }
@@ -56,6 +59,7 @@ class HighsDomain {
     static Reason conflictingBounds(HighsInt pos) {
       return Reason{kConflictingBounds, pos};
     }
+    static Reason objective() { return Reason{kObjective, 0}; }
   };
 
   class ConflictSet {
@@ -223,6 +227,60 @@ class HighsDomain {
   };
 
  private:
+  struct ObjectivePropagation {
+    HighsDomain* domain = nullptr;
+    const HighsObjectiveFunction* objFunc;
+    const double* cost;
+    HighsCDouble objectiveLower;
+    HighsInt numInfObjLower;
+    double capacityThreshold;
+    bool isPropagated;
+
+    struct ObjectiveContribution {
+      double contribution;
+      HighsInt col;
+      HighsInt partition;
+      highs::RbTreeLinks<HighsInt> links;
+    };
+
+    class ObjectiveContributionTree;
+
+    std::vector<ObjectiveContribution> objectiveLowerContributions;
+    std::vector<std::pair<HighsInt, HighsInt>> contributionPartitionSets;
+    std::vector<double> propagationConsBuffer;
+    struct PartitionCliqueData {
+      double multiplier;
+      HighsInt rhs;
+      bool changed;
+    };
+
+    std::vector<PartitionCliqueData> partitionCliqueData;
+
+    ObjectivePropagation() = default;
+    ObjectivePropagation(HighsDomain* domain);
+
+    bool isActive() const { return domain != nullptr; }
+
+    void updateActivityLbChange(HighsInt col, double oldbound, double newbound);
+
+    void updateActivityUbChange(HighsInt col, double oldbound, double newbound);
+
+    bool shouldBePropagated() const;
+
+    void propagate();
+
+    void debugCheckObjectiveLower() const;
+
+    // construct the proot constraint at the time when the domain change stack
+    // had the given size
+    void getPropagationConstraint(HighsInt domchgStackSize, const double*& vals,
+                                  const HighsInt*& inds, HighsInt& len,
+                                  double& rhs, HighsInt domchgCol = -1);
+
+   private:
+    void recomputeCapacityThreshold();
+  };
+
   std::vector<uint8_t> changedcolsflags_;
   std::vector<HighsInt> changedcols_;
 
@@ -239,6 +297,7 @@ class HighsDomain {
   std::vector<double> capacityThreshold_;
   std::vector<uint8_t> propagateflags_;
   std::vector<HighsInt> propagateinds_;
+  ObjectivePropagation objProp_;
 
   HighsMipSolver* mipsolver;
 
@@ -287,6 +346,7 @@ class HighsDomain {
         capacityThreshold_(other.capacityThreshold_),
         propagateflags_(other.propagateflags_),
         propagateinds_(other.propagateinds_),
+        objProp_(other.objProp_),
         mipsolver(other.mipsolver),
         cutpoolpropagation(other.cutpoolpropagation),
         conflictPoolPropagation(other.conflictPoolPropagation),
@@ -301,6 +361,7 @@ class HighsDomain {
       cutpoolprop.domain = this;
     for (ConflictPoolPropagation& conflictprop : conflictPoolPropagation)
       conflictprop.domain = this;
+    if (objProp_.domain) objProp_.domain = this;
   }
 
   HighsDomain& operator=(const HighsDomain& other) {
@@ -316,6 +377,7 @@ class HighsDomain {
     capacityThreshold_ = other.capacityThreshold_;
     propagateflags_ = other.propagateflags_;
     propagateinds_ = other.propagateinds_;
+    objProp_ = other.objProp_;
     mipsolver = other.mipsolver;
     cutpoolpropagation = other.cutpoolpropagation;
     conflictPoolPropagation = other.conflictPoolPropagation;
@@ -330,6 +392,7 @@ class HighsDomain {
       cutpoolprop.domain = this;
     for (ConflictPoolPropagation& conflictprop : conflictPoolPropagation)
       conflictprop.domain = this;
+    if (objProp_.domain) objProp_.domain = this;
     return *this;
   }
 
@@ -341,6 +404,10 @@ class HighsDomain {
                           const double* ARvalue, HighsInt& ninfmax,
                           HighsCDouble& activitymax);
 
+  double adjustedUb(HighsInt col, HighsCDouble boundVal, bool& accept) const;
+
+  double adjustedLb(HighsInt col, HighsCDouble boundVal, bool& accept) const;
+
   HighsInt propagateRowUpper(const HighsInt* Rindex, const double* Rvalue,
                              HighsInt Rlen, double Rupper,
                              const HighsCDouble& minactivity, HighsInt ninfmin,
@@ -391,6 +458,8 @@ class HighsDomain {
 
   void markPropagateCut(Reason reason);
 
+  void setupObjectivePropagation() { objProp_ = ObjectivePropagation(this); }
+
   void computeRowActivities();
 
   void markInfeasible(Reason reason = Reason::unspecified()) {
@@ -440,6 +509,13 @@ class HighsDomain {
     return domchgreason_;
   }
 
+  double getObjectiveLowerBound() const {
+    if (objProp_.isActive() && objProp_.numInfObjLower == 0)
+      return double(objProp_.objectiveLower);
+
+    return -kHighsInf;
+  }
+
   HighsInt getNumDomainChanges() const { return domchgstack_.size(); }
 
   bool colBoundsAreGlobal(HighsInt col) const {
