@@ -29,6 +29,8 @@
 #include "util/HighsCDouble.h"
 #include "util/HighsIntegers.h"
 
+using std::fabs;
+
 HighsMipSolver::HighsMipSolver(const HighsOptions& options, const HighsLp& lp,
                                const HighsSolution& solution, bool submip)
     : options_mip_(&options),
@@ -48,25 +50,42 @@ HighsMipSolver::HighsMipSolver(const HighsOptions& options, const HighsLp& lp,
     HighsCDouble obj = orig_model_->offset_;
     assert((HighsInt)solution.col_value.size() == orig_model_->num_col_);
     for (HighsInt i = 0; i != orig_model_->num_col_; ++i) {
-      obj += orig_model_->col_cost_[i] * solution.col_value[i];
-
-      bound_violation_ = std::max(
-          bound_violation_, orig_model_->col_lower_[i] - solution.col_value[i]);
-      bound_violation_ = std::max(
-          bound_violation_, solution.col_value[i] - orig_model_->col_upper_[i]);
+      const double value = solution.col_value[i];
+      obj += orig_model_->col_cost_[i] * value;
 
       if (orig_model_->integrality_[i] == HighsVarType::kInteger) {
-        double intval = std::floor(solution.col_value[i] + 0.5);
-        integrality_violation_ = std::max(
-            std::abs(intval - solution.col_value[i]), integrality_violation_);
+        double intval = std::floor(value + 0.5);
+        integrality_violation_ =
+            std::max(fabs(intval - value), integrality_violation_);
       }
+
+      const double lower = orig_model_->col_lower_[i];
+      const double upper = orig_model_->col_upper_[i];
+      double primal_infeasibility;
+      if (value < lower - options_mip_->mip_feasibility_tolerance) {
+        primal_infeasibility = lower - value;
+      } else if (value > upper + options_mip_->mip_feasibility_tolerance) {
+        primal_infeasibility = value - upper;
+      } else
+        continue;
+
+      bound_violation_ = std::max(bound_violation_, primal_infeasibility);
     }
 
     for (HighsInt i = 0; i != orig_model_->num_row_; ++i) {
-      row_violation_ = std::max(
-          row_violation_, orig_model_->row_lower_[i] - solution.row_value[i]);
-      row_violation_ = std::max(
-          row_violation_, solution.row_value[i] - orig_model_->row_upper_[i]);
+      const double value = solution.row_value[i];
+      const double lower = orig_model_->row_lower_[i];
+      const double upper = orig_model_->row_upper_[i];
+
+      double primal_infeasibility;
+      if (value < lower - options_mip_->mip_feasibility_tolerance) {
+        primal_infeasibility = lower - value;
+      } else if (value > upper + options_mip_->mip_feasibility_tolerance) {
+        primal_infeasibility = value - upper;
+      } else
+        continue;
+
+      row_violation_ = std::max(row_violation_, primal_infeasibility);
     }
 
     solution_objective_ = double(obj);
@@ -436,11 +455,12 @@ void HighsMipSolver::cleanupSolve() {
   timer_.start(timer_.postsolve_clock);
   bool havesolution = solution_objective_ != kHighsInf;
   dual_bound_ = mipdata_->lower_bound;
-  if (mipdata_->objintscale != 0.0) {
+  if (mipdata_->objectiveFunction.isIntegral()) {
     double rounded_lower_bound =
-        std::ceil(mipdata_->lower_bound * mipdata_->objintscale -
+        std::ceil(mipdata_->lower_bound *
+                      mipdata_->objectiveFunction.integralScale() -
                   mipdata_->feastol) /
-        mipdata_->objintscale;
+        mipdata_->objectiveFunction.integralScale();
     dual_bound_ = std::max(dual_bound_, rounded_lower_bound);
   }
   dual_bound_ += model_->offset_;
@@ -448,7 +468,14 @@ void HighsMipSolver::cleanupSolve() {
   node_count_ = mipdata_->num_nodes;
   dual_bound_ = std::min(dual_bound_, primal_bound_);
 
-  if (modelstatus_ == HighsModelStatus::kNotset) {
+  // adjust objective sense in case of maximization problem
+  if (orig_model_->sense_ == ObjSense::kMaximize) {
+    dual_bound_ = -dual_bound_;
+    primal_bound_ = -primal_bound_;
+  }
+
+  if (modelstatus_ == HighsModelStatus::kNotset ||
+      modelstatus_ == HighsModelStatus::kInfeasible) {
     if (havesolution)
       modelstatus_ = HighsModelStatus::kOptimal;
     else
@@ -467,21 +494,22 @@ void HighsMipSolver::cleanupSolve() {
     solutionstatus = feasible ? "feasible" : "infeasible";
   }
 
-  double gap = fabs(primal_bound_ - dual_bound_);
+  gap_ = fabs(primal_bound_ - dual_bound_);
   if (primal_bound_ == 0.0)
-    gap = dual_bound_ == 0.0 ? 0.0 : kHighsInf;
+    gap_ = dual_bound_ == 0.0 ? 0.0 : kHighsInf;
   else if (primal_bound_ != kHighsInf)
-    gap = fabs(primal_bound_ - dual_bound_) / fabs(primal_bound_);
+    gap_ = fabs(primal_bound_ - dual_bound_) / fabs(primal_bound_);
   else
-    gap = kHighsInf;
+    gap_ = kHighsInf;
+
   std::array<char, 128> gapString;
 
-  if (gap == kHighsInf)
+  if (gap_ == kHighsInf)
     std::strcpy(gapString.data(), "inf");
   else {
-    double printTol = std::max(std::min(1e-2, 1e-1 * gap), 1e-6);
+    double printTol = std::max(std::min(1e-2, 1e-1 * gap_), 1e-6);
     std::array<char, 32> gapValString =
-        highsDoubleToString(100.0 * gap, printTol);
+        highsDoubleToString(100.0 * gap_, printTol);
     double gapTol = options_mip_->mip_rel_gap;
 
     if (options_mip_->mip_abs_gap > options_mip_->mip_feasibility_tolerance) {
