@@ -150,22 +150,25 @@ void HighsMipSolverData::finishAnalyticCenterComputation(
 double HighsMipSolverData::computeNewUpperLimit(double ub, double mip_abs_gap,
                                                 double mip_rel_gap) const {
   double new_upper_limit;
-  if (objintscale != 0.0) {
-    new_upper_limit = (std::floor(objintscale * ub - 0.5) / objintscale);
+  if (objectiveFunction.isIntegral()) {
+    new_upper_limit =
+        (std::floor(objectiveFunction.integralScale() * ub - 0.5) /
+         objectiveFunction.integralScale());
 
     if (mip_rel_gap != 0.0)
       new_upper_limit = std::min(
           new_upper_limit,
           ub - std::ceil(mip_rel_gap * fabs(ub + mipsolver.model_->offset_) *
-                             objintscale -
+                             objectiveFunction.integralScale() -
                          mipsolver.mipdata_->epsilon) /
-                   objintscale);
+                   objectiveFunction.integralScale());
 
     if (mip_abs_gap != 0.0)
-      new_upper_limit = std::min(new_upper_limit,
-                                 ub - std::ceil(mip_abs_gap * objintscale -
-                                                mipsolver.mipdata_->epsilon) /
-                                          objintscale);
+      new_upper_limit = std::min(
+          new_upper_limit,
+          ub - std::ceil(mip_abs_gap * objectiveFunction.integralScale() -
+                         mipsolver.mipdata_->epsilon) /
+                   objectiveFunction.integralScale());
 
     // add feasibility tolerance so that the next best integer feasible solution
     // is definitely included in the remaining search
@@ -314,7 +317,6 @@ void HighsMipSolverData::init() {
   upper_bound = kHighsInf;
   upper_limit = mipsolver.options_mip_->objective_bound;
   optimality_limit = mipsolver.options_mip_->objective_bound;
-  objintscale = 0.0;
 
   if (mipsolver.options_mip_->mip_report_level == 0)
     dispfreq = 0;
@@ -358,13 +360,12 @@ void HighsMipSolverData::runSetup() {
   if (mipsolver.solution_objective_ != kHighsInf) {
     incumbent = postSolveStack.getReducedPrimalSolution(mipsolver.solution_);
     double solobj = mipsolver.solution_objective_ - mipsolver.model_->offset_;
-    bool feasible =
-        mipsolver.bound_violation_ <=
-            mipsolver.options_mip_->mip_feasibility_tolerance &&
-        mipsolver.integrality_violation_ <=
-            mipsolver.options_mip_->mip_feasibility_tolerance &&
-        mipsolver.row_violation_ <=
-            mipsolver.options_mip_->mip_feasibility_tolerance + kHighsTiny;
+    bool feasible = mipsolver.bound_violation_ <=
+                        mipsolver.options_mip_->mip_feasibility_tolerance &&
+                    mipsolver.integrality_violation_ <=
+                        mipsolver.options_mip_->mip_feasibility_tolerance &&
+                    mipsolver.row_violation_ <=
+                        mipsolver.options_mip_->mip_feasibility_tolerance;
     if (numRestarts == 0) {
       highsLogUser(mipsolver.options_mip_->log_options, HighsLogType::kInfo,
                    "\nMIP start solution is %s, objective value is %.12g\n",
@@ -464,6 +465,8 @@ void HighsMipSolverData::runSetup() {
   }
 
   // compute row activities and propagate all rows once
+  objectiveFunction.setupCliquePartition(domain, cliquetable);
+  domain.setupObjectivePropagation();
   domain.computeRowActivities();
   domain.propagate();
   if (domain.infeasible()) {
@@ -625,11 +628,11 @@ double HighsMipSolverData::transformNewIncumbent(
     const std::vector<double>& sol) {
   HighsSolution solution;
   solution.col_value = sol;
-  calculateRowValues(*mipsolver.model_, solution);
+  calculateRowValuesQuad(*mipsolver.orig_model_, solution);
   solution.value_valid = true;
 
   postSolveStack.undoPrimal(*mipsolver.options_mip_, solution);
-  calculateRowValues(*mipsolver.orig_model_, solution);
+  calculateRowValuesQuad(*mipsolver.orig_model_, solution);
   bool allow_try_again = true;
 try_again:
 
@@ -642,37 +645,50 @@ try_again:
   assert((HighsInt)solution.col_value.size() ==
          mipsolver.orig_model_->num_col_);
   for (HighsInt i = 0; i != mipsolver.orig_model_->num_col_; ++i) {
-    obj += mipsolver.orig_model_->col_cost_[i] * solution.col_value[i];
-
-    bound_violation_ =
-        std::max(bound_violation_,
-                 mipsolver.orig_model_->col_lower_[i] - solution.col_value[i]);
-    bound_violation_ =
-        std::max(bound_violation_,
-                 solution.col_value[i] - mipsolver.orig_model_->col_upper_[i]);
+    const double value = solution.col_value[i];
+    obj += mipsolver.orig_model_->col_cost_[i] * value;
 
     if (mipsolver.orig_model_->integrality_[i] == HighsVarType::kInteger) {
-      double intval = std::floor(solution.col_value[i] + 0.5);
-      integrality_violation_ = std::max(
-          std::abs(intval - solution.col_value[i]), integrality_violation_);
+      double intval = std::floor(value + 0.5);
+      integrality_violation_ =
+          std::max(std::fabs(intval - value), integrality_violation_);
     }
+
+    const double lower = mipsolver.orig_model_->col_lower_[i];
+    const double upper = mipsolver.orig_model_->col_upper_[i];
+    double primal_infeasibility = 0;
+    if (value < lower - mipsolver.options_mip_->mip_feasibility_tolerance) {
+      primal_infeasibility = lower - value;
+    } else if (value >
+               upper + mipsolver.options_mip_->mip_feasibility_tolerance) {
+      primal_infeasibility = value - upper;
+    } else
+      continue;
+
+    bound_violation_ = std::max(bound_violation_, primal_infeasibility);
   }
 
   for (HighsInt i = 0; i != mipsolver.orig_model_->num_row_; ++i) {
-    row_violation_ =
-        std::max(row_violation_,
-                 mipsolver.orig_model_->row_lower_[i] - solution.row_value[i]);
-    row_violation_ =
-        std::max(row_violation_,
-                 solution.row_value[i] - mipsolver.orig_model_->row_upper_[i]);
+    const double value = solution.row_value[i];
+    const double lower = mipsolver.orig_model_->row_lower_[i];
+    const double upper = mipsolver.orig_model_->row_upper_[i];
+    double primal_infeasibility;
+    if (value < lower - mipsolver.options_mip_->mip_feasibility_tolerance) {
+      primal_infeasibility = lower - value;
+    } else if (value >
+               upper + mipsolver.options_mip_->mip_feasibility_tolerance) {
+      primal_infeasibility = value - upper;
+    } else
+      continue;
+
+    row_violation_ = std::max(row_violation_, primal_infeasibility);
   }
 
   bool feasible =
       bound_violation_ <= mipsolver.options_mip_->mip_feasibility_tolerance &&
       integrality_violation_ <=
           mipsolver.options_mip_->mip_feasibility_tolerance &&
-      row_violation_ <=
-          mipsolver.options_mip_->mip_feasibility_tolerance + kHighsTiny;
+      row_violation_ <= mipsolver.options_mip_->mip_feasibility_tolerance;
 
   if (!feasible && allow_try_again) {
     // printf(
@@ -722,7 +738,7 @@ try_again:
         mipsolver.integrality_violation_ <=
             mipsolver.options_mip_->mip_feasibility_tolerance &&
         mipsolver.row_violation_ <=
-            mipsolver.options_mip_->mip_feasibility_tolerance + kHighsTiny;
+            mipsolver.options_mip_->mip_feasibility_tolerance;
     highsLogUser(
         mipsolver.options_mip_->log_options, HighsLogType::kWarning,
         "Untransformed solution with objective %g is violated by %.12g for the "
@@ -1007,7 +1023,7 @@ void HighsMipSolverData::printDisplayLine(char first) {
   if (upper_bound != kHighsInf) {
     ub = upper_bound + offset;
 
-    if (std::abs(ub) <= epsilon) ub = 0;
+    if (std::fabs(ub) <= epsilon) ub = 0;
     lb = std::min(ub, lb);
     if (ub == 0.0)
       gap = lb == 0.0 ? 0.0 : kHighsInf;
@@ -1023,11 +1039,13 @@ void HighsMipSolverData::printDisplayLine(char first) {
     std::array<char, 16> ub_string;
     if (mipsolver.options_mip_->objective_bound < ub) {
       ub = mipsolver.options_mip_->objective_bound;
-      ub_string = convertToPrintString(ub, "*");
+      ub_string =
+          convertToPrintString((int)mipsolver.orig_model_->sense_ * ub, "*");
     } else
-      ub_string = convertToPrintString(ub);
+      ub_string = convertToPrintString((int)mipsolver.orig_model_->sense_ * ub);
 
-    std::array<char, 16> lb_string = convertToPrintString(lb);
+    std::array<char, 16> lb_string =
+        convertToPrintString((int)mipsolver.orig_model_->sense_ * lb);
 
     highsLogUser(
         mipsolver.options_mip_->log_options, HighsLogType::kInfo,
@@ -1042,11 +1060,13 @@ void HighsMipSolverData::printDisplayLine(char first) {
     std::array<char, 16> ub_string;
     if (mipsolver.options_mip_->objective_bound < ub) {
       ub = mipsolver.options_mip_->objective_bound;
-      ub_string = convertToPrintString(ub, "*");
+      ub_string =
+          convertToPrintString((int)mipsolver.orig_model_->sense_ * ub, "*");
     } else
-      ub_string = convertToPrintString(ub);
+      ub_string = convertToPrintString((int)mipsolver.orig_model_->sense_ * ub);
 
-    std::array<char, 16> lb_string = convertToPrintString(lb);
+    std::array<char, 16> lb_string =
+        convertToPrintString((int)mipsolver.orig_model_->sense_ * lb);
 
     highsLogUser(
         mipsolver.options_mip_->log_options, HighsLogType::kInfo,
@@ -1189,15 +1209,12 @@ restart:
   lp.loadModel();
   domain.clearChangedCols();
   lp.setObjectiveLimit(upper_limit);
+  lower_bound = std::max(lower_bound, domain.getObjectiveLowerBound());
 
   if (symmetries.numPerms != 0)
     globalOrbits = symmetries.computeStabilizerOrbits(domain);
 
-  if (numRestarts == 0) {
-    // solve the first root lp
-    highsLogUser(mipsolver.options_mip_->log_options, HighsLogType::kInfo,
-                 "\nSolving root node LP relaxation\n");
-  }
+  printDisplayLine();
 
   if (firstrootbasis.valid)
     lp.getLpSolver().setBasis(firstrootbasis,
@@ -1261,6 +1278,9 @@ restart:
 
   lp.setIterationLimit(std::max(10000, int(10 * avgrootlpiters)));
 
+  // make sure first line after solving root LP is printed
+  last_disptime = -kHighsInf;
+
   heuristics.randomizedRounding(firstlpsol);
   heuristics.flushStatistics();
 
@@ -1547,43 +1567,11 @@ bool HighsMipSolverData::checkLimits(int64_t nodeOffset) const {
 }
 
 void HighsMipSolverData::checkObjIntegrality() {
-  objintscale = 600.0;
-
-  for (HighsInt i = 0; i != mipsolver.numCol(); ++i) {
-    if (mipsolver.colCost(i) == 0.0) continue;
-
-    if (mipsolver.variableType(i) == HighsVarType::kContinuous) {
-      objintscale = 0.0;
-      break;
-    }
-
-    double cost = mipsolver.colCost(i);
-    double intcost = std::floor(objintscale * cost + 0.5) / objintscale;
-    if (std::abs(cost - intcost) > epsilon) {
-      objintscale = 0.0;
-      break;
-    }
-  }
-
-  if (objintscale != 0.0) {
-    int64_t currgcd = 0;
-    for (HighsInt i = 0; i != mipsolver.numCol(); ++i) {
-      if (mipsolver.colCost(i) == 0.0) continue;
-      int64_t intval = std::floor(mipsolver.colCost(i) * objintscale + 0.5);
-      if (currgcd == 0) {
-        currgcd = intval < 0 ? -intval : intval;
-        continue;
-      }
-      currgcd = HighsIntegers::gcd(intval, currgcd);
-      if (currgcd == 1) break;
-    }
-
-    if (currgcd != 0) objintscale /= currgcd;
-
-    if (numRestarts == 0)
-      highsLogUser(mipsolver.options_mip_->log_options, HighsLogType::kInfo,
-                   "Objective function is integral with scale %g\n",
-                   objintscale);
+  objectiveFunction.checkIntegrality(epsilon);
+  if (objectiveFunction.isIntegral() && numRestarts == 0) {
+    highsLogUser(mipsolver.options_mip_->log_options, HighsLogType::kInfo,
+                 "Objective function is integral with scale %g\n",
+                 objectiveFunction.integralScale());
   }
 }
 
